package Games::ABC_Path::Generator::App;
$Games::ABC_Path::Generator::App::VERSION = '0.6.1';
use 5.006;
use strict;
use warnings;

use Pod::Usage qw(pod2usage);

use parent 'Games::ABC_Path::Generator::Base';

use Getopt::Long qw(GetOptionsFromArray);

use Games::ABC_Path::Generator;


sub _argv
{
    my $self = shift;

    if (@_)
    {
        $self->{_argv} = shift;
    }

    return $self->{_argv};
}

sub _init
{
    my ( $self, $args ) = @_;

    $self->_argv( $args->{argv} );

    return;
}


sub run
{
    my ($self) = @_;

    my $seed;
    my $mode = 'riddle';
    my $man  = 0;
    my $help = 0;
    if (
        !GetOptionsFromArray(
            $self->_argv(),
            'seed=i' => \$seed,
            'mode=s' => \$mode,
            'help|h' => \$help,
            man      => \$man,
        )
        )
    {
        pod2usage(2);
    }

    if ($help)
    {
        pod2usage(1);
    }
    elsif ($man)
    {
        pod2usage( -verbose => 2 );
    }
    elsif ( !defined($seed) )
    {
        die "Seed not specified! See --help.";
    }
    else
    {
        my $gen = Games::ABC_Path::Generator->new( { seed => $seed, } );

        if ( $mode eq 'final' )
        {
            print $gen->calc_final_layout()->as_string( {} );
        }
        elsif ( $mode eq 'riddle' )
        {
            my $riddle        = $gen->calc_riddle();
            my $riddle_string = $riddle->get_riddle_v1_string;

            print sprintf( "ABC Path Solver Layout Version 1:\n%s",
                $riddle_string, );
        }

    }
    return;
}


1;    # End of Games::ABC_Path::Generator::App

__END__

=pod

=encoding UTF-8

=head1 NAME

Games::ABC_Path::Generator::App - command line application for the ABC Path generator.

=head1 VERSION

version 0.6.1

=head1 SYNOPSIS

    use Games::ABC_Path::Generator::App;

    my $app = Games::ABC_Path::Generator::App->new({ argv => \@ARGV, },);
    $app->run();

=head1 SUBROUTINES/METHODS

=head2 Games::ABC_Path::Generator::App->new({ argv => \@ARGV, },);

Initialize from @ARGV .

=head2 $app->run()

Runs the application.

=head1 AUTHOR

Shlomi Fish, L<http://www.shlomifish.org/> .

=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan

=head1 SUPPORT

=head2 Websites

The following websites have more information about this module, and may be of help to you. As always,
in addition to those websites please use your favorite search engine to discover more resources.

=over 4

=item *

MetaCPAN

A modern, open-source CPAN search engine, useful to view POD in HTML format.

L<https://metacpan.org/release/Games-ABC_Path-Generator>

=item *

RT: CPAN's Bug Tracker

The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.

L<https://rt.cpan.org/Public/Dist/Display.html?Name=Games-ABC_Path-Generator>

=item *

CPANTS

The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.

L<http://cpants.cpanauthors.org/dist/Games-ABC_Path-Generator>

=item *

CPAN Testers

The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.

L<http://www.cpantesters.org/distro/G/Games-ABC_Path-Generator>

=item *

CPAN Testers Matrix

The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.

L<http://matrix.cpantesters.org/?dist=Games-ABC_Path-Generator>

=item *

CPAN Testers Dependencies

The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.

L<http://deps.cpantesters.org/?module=Games::ABC_Path::Generator>

=back

=head2 Bugs / Feature Requests

Please report any bugs or feature requests by email to C<bug-games-abc_path-generator at rt.cpan.org>, or through
the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=Games-ABC_Path-Generator>. You will be automatically notified of any
progress on the request by the system.

=head2 Source Code

The code is open to the world, and available for you to hack on. Please feel free to browse it and play
with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
from your repository :)

L<https://github.com/shlomif/abc-path>

  git clone https://github.com/shlomif/abc-path

=head1 AUTHOR

Shlomi Fish <shlomif@cpan.org>

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website
L<https://github.com/shlomif/abc-path/issues>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2025 by Shlomi Fish.

This is free software, licensed under:

  The MIT (X11) License

=cut
